# LiHiSTO: List of Hindi STOpwords
A package with a comprehensive list of 820 Hindi Stopwords.

## Installation

```bash
pip install LiHiSTO==0.0.2
```

## Usage

```bash
>>> from stopwords_hindi import hindi_sw
>>> sw = hindi_sw.get_hindi_sw()
>>> len(sw)
820

```

## Citation ##
If you find this useful, please cite the work as follows:

    @article{Swati2022,
        title = {LiHiSTO: a Comprehensive List of Hindi Stopwords},
        author = {Rajwal, Swati},
        journal = {},
        year = {2022},
        month = {},
        volume = {}, 
        number = {}, 
        pages = {}, 
        doi = {}, 
        ISSN = {}, 
    }

## Licence ##
- MIT License